@@ -27,6 +27,7 @@
 #include <config.h>
 #endif
 #include "fribidi.h"
+#include "fribidi_mem.h"
 #ifdef DEBUG
 #include <stdio.h>
 #endif
@@ -41,8 +42,8 @@
 #endif
 
 #ifdef DEBUG
-#define DBG(s) do { if (fribidi_debug) { fprintf(stderr, s); } } while (0)
-#define DBG2(s, t) do { if (fribidi_debug) { fprintf(stderr, s, t); } } while (0)
+#define DBG(s) do { if (fribidi_debug_status(fribidienv)) { fprintf(stderr, s); } } while (0)
+#define DBG2(s, t) do { if (fribidi_debug_status(fribidienv)) { fprintf(stderr, s, t); } } while (0)
 #else
 #define DBG(s)
 #define DBG2(s, t)
@@ -95,7 +96,8 @@ fribidi_set_debug (fribidi_boolean debug)
 }
 
 static void
-bidi_string_reverse (FriBidiChar *str, FriBidiStrIndex len)
+bidi_string_reverse (FriBidiChar *str,
+		     FriBidiStrIndex len)
 {
   FriBidiStrIndex i;
   for (i = 0; i < len / 2; i++)
@@ -107,7 +109,8 @@ bidi_string_reverse (FriBidiChar *str, FriBidiStrIndex len)
 }
 
 static void
-index_array_reverse (FriBidiStrIndex *arr, FriBidiStrIndex len)
+index_array_reverse (FriBidiStrIndex *arr,
+		     FriBidiStrIndex len)
 {
   FriBidiStrIndex i;
   for (i = 0; i < len / 2; i++)
@@ -140,11 +143,12 @@ new_type_link (void)
       static FriBidiMemChunk *mem_chunk = NULL;
 
       if (!mem_chunk)
-	mem_chunk =
-	  fribidi_mem_chunk_create (TypeLink, FRIBIDI_CHUNK_SIZE,
-				    FRIBIDI_ALLOC_ONLY);
+	mem_chunk = fribidi_mem_chunk_create (TypeLink,
+					      FRIBIDI_CHUNK_SIZE,
+					      FRIBIDI_ALLOC_ONLY);
 
-      link = fribidi_chunk_new (TypeLink, mem_chunk);
+      link = fribidi_chunk_new (TypeLink,
+				mem_chunk);
     }
 #endif /* !USE_SIMPLE_MALLOC */
 
@@ -176,7 +180,8 @@ free_type_link (TypeLink *link)
 	} while (0)
 
 static TypeLink *
-run_length_encode_types (FriBidiCharType *char_type, FriBidiStrIndex type_len)
+run_length_encode_types (FriBidiCharType *char_type,
+			 FriBidiStrIndex type_len)
 {
   TypeLink *list, *last, *link;
 
@@ -213,7 +218,8 @@ run_length_encode_types (FriBidiCharType *char_type, FriBidiStrIndex type_len)
    the override_list.
 */
 static void
-init_list (TypeLink **start, TypeLink **end)
+init_list (TypeLink **start,
+	   TypeLink **end)
 {
   TypeLink *list;
   TypeLink *link;
@@ -244,7 +250,8 @@ init_list (TypeLink **start, TypeLink **end)
    the list that p is currently in, if any.
 */
 static void
-move_element_before (TypeLink *p, TypeLink *list)
+move_element_before (TypeLink *p,
+		     TypeLink *list)
 {
   if (p->prev)
     {
@@ -272,7 +279,8 @@ move_element_before (TypeLink *p, TypeLink *list)
    TBD: use some explanatory names instead of p, q, ...
 */
 static void
-override_list (TypeLink *base, TypeLink *over)
+override_list (TypeLink *base,
+	       TypeLink *over)
 {
   TypeLink *p = base, *q, *r, *s, *t;
   FriBidiStrIndex pos = 0, pos2;
@@ -582,10 +590,12 @@ print_bidi_string (FriBidiChar *str)
  *----------------------------------------------------------------------*/
 static void
 fribidi_analyse_string (	/* input */
-			 FriBidiChar *str, FriBidiStrIndex len,
+			 FriBidiChar *str,
+			 FriBidiStrIndex len,
 			 FriBidiCharType *pbase_dir,
 			 /* output */
-			 TypeLink **ptype_rl_list, FriBidiLevel *pmax_level)
+			 TypeLink **ptype_rl_list,
+			 FriBidiLevel *pmax_level)
 {
   FriBidiLevel base_level, max_level;
   FriBidiCharType base_dir;
@@ -1071,13 +1081,13 @@ free_rl_list (TypeLink *type_rl_list)
 
 static fribidi_boolean mirroring = FRIBIDI_TRUE;
 
-fribidi_boolean
+FRIBIDI_API fribidi_boolean
 fribidi_mirroring_status (void)
 {
   return mirroring;
 }
 
-void
+FRIBIDI_API void
 fribidi_set_mirroring (fribidi_boolean mirror)
 {
   mirroring = mirror;
@@ -1091,7 +1101,7 @@ fribidi_reorder_nsm_status (void)
   return reorder_nsm;
 }
 
-void
+FRIBIDI_API void
 fribidi_set_reorder_nsm (fribidi_boolean reorder)
 {
   reorder_nsm = reorder;
@@ -1105,8 +1115,9 @@ fribidi_set_reorder_nsm (fribidi_boolean reorder)
  *  fribidi_remove_bidi_marks() removes bidirectional marks, and returns
  *  the new length, updates each of other inputs if not NULL.
  *----------------------------------------------------------------------*/
-FriBidiStrIndex
-fribidi_remove_bidi_marks (FriBidiChar *str, FriBidiStrIndex length,
+FRIBIDI_API FriBidiStrIndex
+fribidi_remove_bidi_marks (FriBidiChar *str,
+			   FriBidiStrIndex length,
 			   FriBidiStrIndex *position_to_this_list,
 			   FriBidiStrIndex *position_from_this_list,
 			   FriBidiLevel *embedding_level_list)
@@ -1161,9 +1172,10 @@ fribidi_remove_bidi_marks (FriBidiChar *str, FriBidiStrIndex length,
  *  fribidi_log2vis() calls the function_analyse_string() and then
  *  does reordering and fills in the output strings.
  *----------------------------------------------------------------------*/
-fribidi_boolean
+FRIBIDI_API fribidi_boolean
 fribidi_log2vis (		/* input */
-		  FriBidiChar *str, FriBidiStrIndex len,
+		  FriBidiChar *str,
+		  FriBidiStrIndex len,
 		  FriBidiCharType *pbase_dir,
 		  /* output */
 		  FriBidiChar *visual_str,
@@ -1279,10 +1291,10 @@ fribidi_log2vis (		/* input */
 	      {
 		if (pp->level & 1)
 		  {
-		    FriBidiStrIndex i;
-		    fribidi_boolean is_nsm_seq, seq_end;
+		    FriBidiStrIndex i, seq_end = 0;
+		    fribidi_boolean is_nsm_seq;
 
-		    is_nsm_seq = 0;
+		    is_nsm_seq = FRIBIDI_FALSE;
 		    for (i = RL_POS (pp) + RL_LEN (pp) - 1; i >= RL_POS (pp);
 			 i--)
 		      {
@@ -1328,7 +1340,8 @@ fribidi_log2vis (		/* input */
 		if (RL_LEVEL (pp) >= level_idx)
 		  {
 		    /* Find all stretches that are >= level_idx */
-		    FriBidiStrIndex len = RL_LEN (pp), pos = RL_POS (pp);
+		    FriBidiStrIndex len = RL_LEN (pp),
+		      pos = RL_POS (pp);
 		    TypeLink *pp1 = pp->next;
 		    while (pp1->next && RL_LEVEL (pp1) >= level_idx)
 		      {
@@ -1371,7 +1384,7 @@ fribidi_log2vis (		/* input */
  *  fribidi_log2vis_get_embedding_levels() is used in order to just get
  *  the embedding levels.
  *----------------------------------------------------------------------*/
-fribidi_boolean
+FRIBIDI_API fribidi_boolean
 fribidi_log2vis_get_embedding_levels (	/* input */
 				       FriBidiChar *str,
 				       FriBidiStrIndex len,
@@ -1396,7 +1409,8 @@ fribidi_log2vis_get_embedding_levels (	/* input */
 
   for (pp = type_rl_list->next; pp->next; pp = pp->next)
     {
-      FriBidiStrIndex i, pos = RL_POS (pp), len = RL_LEN (pp);
+      FriBidiStrIndex i, pos = RL_POS (pp),
+        len = RL_LEN (pp);
       FriBidiLevel level = RL_LEVEL (pp);
       for (i = 0; i < len; i++)
 	embedding_level_list[pos + i] = level;
@@ -1411,11 +1425,13 @@ fribidi_log2vis_get_embedding_levels (	/* input */
 
 
 const char *fribidi_version_info =
-  FRIBIDI_PACKAGE " " FRIBIDI_VERSION "\n"
-  "interface version " FRIBIDI_INTERFACE_VERSION_STR "\n"
+  FRIBIDI_PACKAGE " " FRIBIDI_VERSION "\n" "interface version "
+  TOSTR (FRIBIDI_INTERFACE_VERSION)
+  "\n"
   "Unicode version " FRIBIDI_UNICODE_VERSION "\n"
   "\n"
-  "Copyright (C) 2002 FriBidi Project (http://fribidi.sf.net/).\n"
+  "Copyright (C) 2001,2002,2005  Behdad Esfahbod <fribidi@behdad.org>.\n"
+  "Copyright (C) 1999,2000 Dov Grobgeld\n"
   FRIBIDI_PACKAGE " comes with NO WARRANTY, to the extent permitted by law.\n"
   "You may redistribute copies of " FRIBIDI_PACKAGE " under the terms of\n"
   "the GNU Lesser General Public License.\n"
@@ -1433,4 +1449,4 @@ const char *fribidi_version_info =
 #ifdef FRIBIDI_NO_CHARSETS
   "--without-charsts\n"
 #endif
- ;
+;
